package xyz.zhouxy.plusone.map;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import org.junit.jupiter.api.Test;

import xyz.zhouxy.plusone.commons.constant.PatternConsts;
import xyz.zhouxy.plusone.validator.MapValidator;

class MapValidatorTests {

    @Test
    void testMapValidator() {
        Map<String, Object> params = new HashMap<>();
        params.put("username", "ZhouXY");
        params.put("admin", true);
        params.put("password", "99Code108");
        params.put("password2", "99Code108");
        params.put("test", "88gggg");
        params.put("roles", Arrays.asList("admin", "ZhongShanAdmin"));

        params = RegisterParamsValidator.INSTANCE
                .validate(params, "roles", "username", "admin", "password");
        System.out.println(params);
    }
}

class RegisterParamsValidator extends MapValidator {
    RegisterParamsValidator() {
        this.<List<String>>ruleFor("roles")
                .notNull(() -> new NullPointerException("roles"));
        this.ruleForString("username")
                .matches(PatternConsts.USERNAME, "用户名不符合条件！");
        this.ruleForBool("admin")
                .notNull("admin could not be null.")
                .isTrue("admin must be true.");
        this.ruleForString("password")
                .notBlank("密码不能为空！")
                .matches(PatternConsts.PASSWORD, "密码格式错误！");
        this.ruleForCollection("roles")
                .notEmpty("角色列表不能为空！");
        this.withRule(m -> Objects.equals(m.get("password"), m.get("password2")),
                "两次输入的密码不一样！");
    }
    static final RegisterParamsValidator INSTANCE = new RegisterParamsValidator();
}
